[gegl] Fix minor typos



commit c9c67f70a6f7fcc30467eded251d5905b572d488
Author: Yuri Chornoivan <yurchor ukr net>
Date:   Sun May 10 18:57:28 2020 +0300

    Fix minor typos

 operations/common/image-gradient.c | 4 ++--
 operations/workshop/band-tune.c    | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/operations/workshop/band-tune.c b/operations/workshop/band-tune.c
index 9d088584f..9d23bf7bd 100644
--- a/operations/workshop/band-tune.c
+++ b/operations/workshop/band-tune.c
@@ -27,7 +27,7 @@ property_double (radius1, _("Detail band"), 1.1)
     value_range (0.0, 100.0)
     ui_range    (0.5, 2.0)
 
-property_double (scale1, _("Detail scale, negative values dimnishes signal in detail band, postivie values 
increases signal."), -1.6)
+property_double (scale1, _("Detail scale, negative values diminish signal in detail band, positive values 
increase signal."), -1.6)
     description(_("Scaling factor for image features at radius, -1 cancels them out 1.0 edge enhances"))
     value_range (-100.0, 100.0)
     ui_range    (-3.0, 3.0)
@@ -43,7 +43,7 @@ property_double (radius2, _("Edge band"), 10.0)
     value_range (0.0, 100.0)
     ui_range    (0.5, 2.0)
 
-property_double (scale2, _("Edge scale, negative values dimnishes signal in detail band, postivie values 
increases signal."), 0.0)
+property_double (scale2, _("Edge scale, negative values diminish signal in detail band, positive values 
increase signal."), 0.0)
     description(_("Scaling factor for image features at radius, -1 cancels them out 1.0 edge enhances"))
     value_range (-100.0, 100.0)
     ui_range    (-3.0, 3.0)


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/operations/common/image-gradient.c b/operations/common/image-gradient.c
index 668e35e8e..1688a8c77 100644
--- a/operations/common/image-gradient.c
+++ b/operations/common/image-gradient.c
@@ -16,7 +16,7 @@
  * Copyright 2016 Thomas Manni <thomas manni free fr>
  */
 
  /* compute gradient magnitude and/or direction by central differencies */
 
 #include "config.h"
 #include <glib/gi18n-lib.h>
@@ -226,7 +226,7 @@ gegl_op_class_init (GeglOpClass *klass)
     "categories",  "edge-detect",
     "reference-hash", "6cd95bf706d744b31b475b3500941f3c",
     "description", _("Compute gradient magnitude and/or direction by "
-                     "central differencies"),
+                     "central differences"),
     NULL);
 }
 
@@ -16,7 +16,7 @@
  */
 
- /* compute gradient magnitude and/or direction by central differencies */
+ /* compute gradient magnitude and/or direction by central differences */
 
 #include "config.h"